@@ -177,8 +177,9 @@ class Base(base.NodeTest):
     def call_get_status(self, uuid, **kwargs):
         return self.call('get', '/v1/introspection/%s' % uuid, **kwargs).json()
 
-    def call_get_data(self, uuid, **kwargs):
-        return self.call('get', '/v1/introspection/%s/data' % uuid,
+    def call_get_data(self, uuid, processed=True, **kwargs):
+        return self.call('get', '/v1/introspection/%s/data%s'
+                         % (uuid, '' if processed else '/unprocessed'),
                          **kwargs).json()
 
     @_query_string('marker', 'limit')
@@ -626,10 +627,14 @@ class Test(Base):
 
         data = self.call_get_data(self.uuid)
         self.assertEqual(self.data['inventory'], data['inventory'])
+        self.assertIn('all_interfaces', data)
+        raw = self.call_get_data(self.uuid, processed=False)
+        self.assertEqual(self.data['inventory'], raw['inventory'])
+        self.assertNotIn('all_interfaces', raw)
 
         res = self.call_reapply(self.uuid)
         self.assertEqual(202, res.status_code)
-        self.assertEqual('', res.text)
+        self.assertEqual('{}\n', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         status = self.call_get_status(self.uuid)
@@ -642,7 +647,7 @@ class Test(Base):
         # second reapply call
         res = self.call_reapply(self.uuid)
         self.assertEqual(202, res.status_code)
-        self.assertEqual('', res.text)
+        self.assertEqual('{}\n', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         # Reapply with provided data
@@ -650,7 +655,7 @@ class Test(Base):
         new_data['inventory']['cpu']['count'] = 42
         res = self.call_reapply(self.uuid, data=new_data)
         self.assertEqual(202, res.status_code)
-        self.assertEqual('', res.text)
+        self.assertEqual('{}\n', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         self.check_status(status, finished=True, state=istate.States.finished)
